==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/gl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Enquisa de uso",
    "Last report sent on: {on}" : "Último informe enviado o: {on}",
    "An error occurred while sending your report." : "Produiuse un erro ao enviar o seu iforme.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicacións <em>(para cada aplicación: nome, versión, estado da activación)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Contorno da base de datos <em>(tipo, versión, tamaño da base de datos)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información do cifrado <em>(está activado?, cal é o módulo predeterminado)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de recursos compartidos <em>(por tipo e configuración de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Contorno PHP PHP<em>(versión, límite de memoria, tempo máx. de execución, tamaño máximo de ficheiro)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalles da instancia do servidor <em>(versión, uso de memcache, estado do bloqueo de ficheiros/vistas previas/avatares)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Estatísticas <em>(número de ficheiros, usuarios, almacenamentos por tipo, comentarios e etiquetas)",
    "Help improve Nextcloud" : "Axuda a mellorar o Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Quere axudarnos a mellorar o Nextcloud achegando algúns datos anónimos sobre os seus axustes e uso? Pode desactivalo en calquera momento na configuración do administrador.",
    "Not now" : "Agora non",
    "Send usage" : "Enviar o uso",
    "Never" : "Nunca",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar o NextCloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar o NextCloud.\n        Vostede terá sempre o control total do contido enviado a Nextcloud e poderá\n        desactivalo en calquera momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Pode axudar a mellorar o Nextcloud enviándonos algúns datos sobre os seus axustes e e uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Tomamonos moi en serio a súa privacidade. O envío de datos está desactivado de xeito predeterminado, e se o activa, o primeiro será anonimizalos e se le lle dará a opción de escoller que é o que quere compartir. Ao recibir un informe, eliminaráse o anterior. Envíe un informe en branco para borrar todos os datos almacenados actualmente no servidor.",
    "Send new report now" : "Enviar agora un novo informe",
    "Send usage survey monthly" : "Enviar a enquisa de uso mensualmente",
    "Data to send" : "Data do envío",
    "Last report sent on: %s" : "O último informe foi enviado o: %s",
    "Last report" : "Último informe",
    "Sent on: {on}" : "Enviado o: {on}",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Estatísticas <em>(número de: ficheiros, usuarios, almacenamentos por tipo, comentarios e etiquetas)",
    "Sent on: %s" : "Enviado o: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/gl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Enquisa de uso",
    "Last report sent on: {on}" : "Último informe enviado o: {on}",
    "An error occurred while sending your report." : "Produiuse un erro ao enviar o seu iforme.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicacións <em>(para cada aplicación: nome, versión, estado da activación)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Contorno da base de datos <em>(tipo, versión, tamaño da base de datos)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información do cifrado <em>(está activado?, cal é o módulo predeterminado)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de recursos compartidos <em>(por tipo e configuración de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Contorno PHP PHP<em>(versión, límite de memoria, tempo máx. de execución, tamaño máximo de ficheiro)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalles da instancia do servidor <em>(versión, uso de memcache, estado do bloqueo de ficheiros/vistas previas/avatares)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Estatísticas <em>(número de ficheiros, usuarios, almacenamentos por tipo, comentarios e etiquetas)",
    "Help improve Nextcloud" : "Axuda a mellorar o Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Quere axudarnos a mellorar o Nextcloud achegando algúns datos anónimos sobre os seus axustes e uso? Pode desactivalo en calquera momento na configuración do administrador.",
    "Not now" : "Agora non",
    "Send usage" : "Enviar o uso",
    "Never" : "Nunca",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar o NextCloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar o NextCloud.\n        Vostede terá sempre o control total do contido enviado a Nextcloud e poderá\n        desactivalo en calquera momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Pode axudar a mellorar o Nextcloud enviándonos algúns datos sobre os seus axustes e e uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Tomamonos moi en serio a súa privacidade. O envío de datos está desactivado de xeito predeterminado, e se o activa, o primeiro será anonimizalos e se le lle dará a opción de escoller que é o que quere compartir. Ao recibir un informe, eliminaráse o anterior. Envíe un informe en branco para eliminar todos os datos almacenados actualmente no servidor.",
    "Send new report now" : "Enviar agora un novo informe",
    "Send usage survey monthly" : "Enviar a enquisa de uso mensualmente",
    "Data to send" : "Data do envío",
    "Last report sent on: %s" : "O último informe foi enviado o: %s",
    "Last report" : "Último informe",
    "Sent on: {on}" : "Enviado o: {on}",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Estatísticas <em>(número de: ficheiros, usuarios, almacenamentos por tipo, comentarios e etiquetas)",
    "Sent on: %s" : "Enviado o: %s"
},
"nplurals=2; plural=(n != 1);");
